@@ -10,7 +10,7 @@ BGJOB=false
 VERBOSE=false
 BASEDIR=`pwd`;
 LIBDIR=${BASEDIR}/libs;
-SUBDIRS="apr libzrtp iksemel srtp fs";
+SUBDIRS="apr iksemel srtp fs";
 
 while getopts 'jhd:v' o; do 
   case "$o" in
@@ -172,10 +172,6 @@ bootstrap_apr() {
 
 }
 
-bootstrap_libzrtp() {
-  (cd ${LIBDIR}/libzrtp && ./bootstrap.sh)
-}
-
 # Libs automake automation function
 libbootstrap() {
   i=$1
@@ -260,7 +256,7 @@ bootstrap_libs_post() {
 bootstrap_libs() {
   for i in ${SUBDIRS}; do
     case "$i" in
-      apr|fs|libzrtp)
+      apr|fs)
         ${BGJOB} && wait
         bootstrap_$i
         continue
