@@ -189,7 +189,6 @@ SWITCH_BEGIN_EXTERN_C
 #define SWITCH_CACHE_SPEECH_HANDLES_OBJ_NAME "__cache_speech_handles_obj__"
 #define SWITCH_BYPASS_MEDIA_VARIABLE "bypass_media"
 #define SWITCH_PROXY_MEDIA_VARIABLE "proxy_media"
-#define SWITCH_ZRTP_PASSTHRU_VARIABLE "zrtp_passthru"
 #define SWITCH_ENDPOINT_DISPOSITION_VARIABLE "endpoint_disposition"
 #define SWITCH_HOLD_MUSIC_VARIABLE "hold_music"
 #define SWITCH_TEMP_HOLD_MUSIC_VARIABLE "temp_hold_music"
@@ -817,10 +816,6 @@ typedef enum {
 	SWITCH_RTP_FLAG_FLUSH,
 	SWITCH_RTP_FLAG_AUTOFLUSH,
 	SWITCH_RTP_FLAG_STICKY_FLUSH,
-	SWITCH_ZRTP_FLAG_SECURE_SEND,
-	SWITCH_ZRTP_FLAG_SECURE_RECV,
-	SWITCH_ZRTP_FLAG_SECURE_MITM_SEND,
-	SWITCH_ZRTP_FLAG_SECURE_MITM_RECV,
 	SWITCH_RTP_FLAG_DEBUG_RTP_READ,
 	SWITCH_RTP_FLAG_DEBUG_RTP_WRITE,
 	SWITCH_RTP_FLAG_ESTIMATORS,
@@ -1208,9 +1203,8 @@ SWITCH_STACK_TOP	- Stack on the top
 typedef enum {
 	SWITCH_STACK_BOTTOM = (1 << 0),
 	SWITCH_STACK_TOP = (1 << 1),
-	SWITCH_STACK_NODUP = (1 << 2),
-	SWITCH_STACK_UNSHIFT = (1 << 3),
-	SWITCH_STACK_PUSH = (1 << 4),
+	SWITCH_STACK_UNSHIFT = (1 << 2),
+	SWITCH_STACK_PUSH = (1 << 3)
 } switch_stack_t;
 
 /*!
@@ -1542,9 +1536,6 @@ typedef enum {
 	CF_MANUAL_MEDIA_PARAMS,
 	CF_SERVICE_AUDIO,
 	CF_SERVICE_VIDEO,
-	CF_ZRTP_PASSTHRU_REQ,
-	CF_ZRTP_PASSTHRU,
-	CF_ZRTP_HASH,
 	CF_CHANNEL_SWAP,
 	CF_DEVICE_LEG,
 	CF_FINAL_DEVICE_LEG,
@@ -1693,20 +1684,19 @@ typedef enum {
 	SFF_RFC2833 = (1 << 4),
 	SFF_PROXY_PACKET = (1 << 5),
 	SFF_DYNAMIC = (1 << 6),
-	SFF_ZRTP = (1 << 7),
-	SFF_UDPTL_PACKET = (1 << 8),
-	SFF_NOT_AUDIO = (1 << 9),
-	SFF_RTCP = (1 << 10),
-	SFF_MARKER = (1 << 11),
-	SFF_WAIT_KEY_FRAME = (1 << 12),
-	SFF_RAW_RTP_PARSE_FRAME = (1 << 13),
-	SFF_PICTURE_RESET = (1 << 14),
-	SFF_SAME_IMAGE = (1 << 15),
-	SFF_USE_VIDEO_TIMESTAMP = (1 << 16),
-	SFF_ENCODED = (1 << 17),
-	SFF_TEXT_LINE_BREAK = (1 << 18),
-	SFF_IS_KEYFRAME = (1 << 19),
-	SFF_EXTERNAL = (1 << 20)
+	SFF_UDPTL_PACKET = (1 << 7),
+	SFF_NOT_AUDIO = (1 << 8),
+	SFF_RTCP = (1 << 9),
+	SFF_MARKER = (1 << 10),
+	SFF_WAIT_KEY_FRAME = (1 << 11),
+	SFF_RAW_RTP_PARSE_FRAME = (1 << 12),
+	SFF_PICTURE_RESET = (1 << 13),
+	SFF_SAME_IMAGE = (1 << 14),
+	SFF_USE_VIDEO_TIMESTAMP = (1 << 15),
+	SFF_ENCODED = (1 << 16),
+	SFF_TEXT_LINE_BREAK = (1 << 17),
+	SFF_IS_KEYFRAME = (1 << 18),
+	SFF_EXTERNAL = (1 << 19)
 } switch_frame_flag_enum_t;
 typedef uint32_t switch_frame_flag_t;
 
