@@ -305,7 +305,7 @@ void conference_event_mod_channel_handler(const char *event_channel, cJSON *json
 	} else if (!strcasecmp(action, "shift-click-layer")) {
 	} else if (!strcasecmp(action, "reset-layer") || !strcasecmp(action, "layer-pan-x") || !strcasecmp(action, "layer-pan-y")) {
 		cJSON *v;
-		int layer_id = 0, canvas_id = 0, metric = 0, absolute = 0;
+		int layer_id = 0, canvas_id = 0, metric = 0;
 		const char *i = "i", *xy = "";
 
 		if ((v = cJSON_GetObjectItem(data, "layerID"))) {
@@ -321,7 +321,7 @@ void conference_event_mod_channel_handler(const char *event_channel, cJSON *json
 		}
 
 		if ((v = cJSON_GetObjectItem(data, "absolute"))) {
-			if ((absolute = v->valueint)) {
+			if (v->valueint) {
 				i = "";
 			}
 		}
