@@ -2378,7 +2378,6 @@ static char *load_cache_data(http_file_context_t *context, const char *url)
 	char digest[SWITCH_MD5_DIGEST_STRING_SIZE] = { 0 };
 	char meta_buffer[1024] = "";
 	int fd;
-	switch_ssize_t bytes;
 
 	switch_md5_string(digest, (void *) url, strlen(url));
 
@@ -2390,7 +2389,7 @@ static char *load_cache_data(http_file_context_t *context, const char *url)
 		ext = find_ext(url);
 	}
 
-	if (ext && (p = strchr(ext, '?'))) {
+	if (ext && strchr(ext, '?')) {
 		dext = strdup(ext);
 		if ((p = strchr(dext, '?'))) {
 			*p = '\0';
@@ -2402,7 +2401,7 @@ static char *load_cache_data(http_file_context_t *context, const char *url)
 	context->meta_file = switch_core_sprintf(context->pool, "%s%s%s.meta", globals.cache_path, SWITCH_PATH_SEPARATOR, digest);
 
 	if (switch_file_exists(context->meta_file, context->pool) == SWITCH_STATUS_SUCCESS && ((fd = open(context->meta_file, O_RDONLY, 0)) > -1)) {
-		if ((bytes = read(fd, meta_buffer, sizeof(meta_buffer))) > 0) {
+		if (read(fd, meta_buffer, sizeof(meta_buffer)) > 0) {
 			char *p;
 
 			if ((p = strchr(meta_buffer, ':'))) {
