@@ -131,6 +131,7 @@ struct local_stream_source {
 	uint8_t logo_opacity;
 	uint8_t text_opacity;
 	switch_mm_t mm;
+	int sync;
 };
 
 typedef struct local_stream_source local_stream_source_t;
@@ -310,6 +311,7 @@ static void *SWITCH_THREAD_FUNC read_stream_thread(switch_thread_t *thread, void
 			switch_size_t olen;
 			const char *artist = NULL, *title = NULL;
 			char tmp_space[128] = "";
+			const char *l;
 
 			if (fd > -1) {
 				char *pb;
@@ -329,7 +331,7 @@ static void *SWITCH_THREAD_FUNC read_stream_thread(switch_thread_t *thread, void
 
 				switch_snprintf(path_buf, sizeof(path_buf), "%s%s%s", source->location, SWITCH_PATH_SEPARATOR, fname);
 
-				if (switch_stristr(".loc", path_buf)) {
+				if ((l = switch_stristr(".loc", fname)) && (l == fname + strlen(fname) - 4)) {
 					if ((fd = open(path_buf, O_RDONLY)) < 0) {
 						switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_ERROR, "Can't open %s\n", fname);
 						switch_yield(1000000);
@@ -362,6 +364,7 @@ static void *SWITCH_THREAD_FUNC read_stream_thread(switch_thread_t *thread, void
 				continue;
 			}
 
+			source->sync = 0;
 			switch_buffer_zero(audio_buffer);
 
 			if (switch_core_file_has_video(&fh, SWITCH_FALSE)) {
@@ -907,7 +910,7 @@ static switch_status_t local_stream_file_open(switch_file_handle_t *handle, cons
 	handle->private_info = context;
 	handle->interval = source->interval;
 	switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_DEBUG, "Opening Stream [%s] %dhz\n", path, handle->samplerate);
-
+	handle->mm.source_fps = source->mm.source_fps;
 	switch_mutex_init(&context->audio_mutex, SWITCH_MUTEX_NESTED, context->pool);
 	if (switch_buffer_create_dynamic(&context->audio_buffer, 512, 1024, 0) != SWITCH_STATUS_SUCCESS) {
 		switch_log_printf(SWITCH_CHANNEL_LOG, SWITCH_LOG_ERROR, "Memory Error!\n");
@@ -999,14 +1002,19 @@ static switch_status_t local_stream_file_read_video(switch_file_handle_t *handle
 	local_stream_context_t *context = handle->private_info;
 	switch_status_t status;
 	switch_time_t now;
-	unsigned int fps = (unsigned int)ceil(handle->mm.fps);
-	unsigned int min_qsize = fps / 2;
-	unsigned int buf_qsize = 5;
+	unsigned int min_qsize = 1;
+	unsigned int buf_qsize = 1;
+
+	handle->mm.source_fps = context->source->mm.source_fps;
 
 	if (!(context->ready && context->source->ready)) {
 		return SWITCH_STATUS_FALSE;
 	}
 
+	if (!context->source->sync) {
+		return SWITCH_STATUS_BREAK;
+	}
+	
 	if (!context->source->has_video) {
 		if (frame) {
 			switch_image_t *src_img = context->source->cover_art;
@@ -1040,11 +1048,6 @@ static switch_status_t local_stream_file_read_video(switch_file_handle_t *handle
 		return SWITCH_STATUS_BREAK;
 	}
 
-	if (handle->mm.fps >= context->source->mm.source_fps) {
-		min_qsize = 1;
-		buf_qsize = 1;
-	}
-
 	while(context->ready && context->source->ready && switch_queue_size(context->video_q) > min_qsize) {
 		if (switch_queue_trypop(context->video_q, &pop) == SWITCH_STATUS_SUCCESS) {
 			switch_image_t *img = (switch_image_t *) pop;
@@ -1170,9 +1173,12 @@ static switch_status_t local_stream_file_read(switch_file_handle_t *handle, void
 
 	if ((bytes = switch_buffer_read(context->audio_buffer, data, need))) {
 		*len = bytes / 2 / context->source->channels;
+		context->source->sync = 1;
 	} else {
 		size_t blank;
 
+		context->source->sync = 0;
+		
 		switch_assert(handle->samplerate <= 48000);
 		switch_assert(handle->real_channels <= 2);
 
@@ -1361,7 +1367,6 @@ SWITCH_STANDARD_API(local_stream_function)
 	char *mycmd = NULL, *argv[5] = { 0 };
 	char *local_stream_name = NULL;
 	int argc = 0;
-	int ok = 0;
 
 	if (zstr(cmd)) {
 		goto usage;
@@ -1455,7 +1460,7 @@ SWITCH_STANDARD_API(local_stream_function)
 			stream->write_function(stream, "+OK stream: %s", source->name);
 			switch_thread_rwlock_unlock(source->rwlock);
 		} else {
-			if ((ok = launch_streams(local_stream_name))) {
+			if (launch_streams(local_stream_name)) {
 				stream->write_function(stream, "+OK stream: %s", local_stream_name);
 			}
 		}
